@@ -32,6 +32,7 @@
 #include "widgetcolumnstylist.h"
 #include "kcursor.h"
 #include "bordercolumnrenderer.h"
+#include "oktetagui.h"
 // Okteta core
 #include <valuecodec.h>
 #include <bookmarkable.h>
@@ -54,7 +55,6 @@ namespace Okteta
 
 static const Address DefaultStartOffset = 0;//5;
 static const Address DefaultFirstLineOffset = 0;
-static const int DefaultNoOfBytesPerLine =  16;
 
 // zooming is done in steps of font size points
 static const int DefaultZoomStep = 1;
@@ -64,7 +64,7 @@ static const int MaxFontPointSize = 128;
 static const AbstractByteArrayView::ValueCoding DefaultValueCoding =  AbstractByteArrayView::HexadecimalCoding;
 static const AbstractByteArrayView::CharCoding DefaultCharCoding = AbstractByteArrayView::LocalEncoding;
 
-static const AbstractByteArrayView::LayoutStyle DefaultResizeStyle = AbstractByteArrayView::FullSizeLayoutStyle;
+static const AbstractByteArrayView::LayoutStyle DefaultResizeStyle = AbstractByteArrayView::FixedLayoutStyle;
 
 static const char OctetStreamFormatName[] = "application/octet-stream";
 
@@ -232,6 +232,8 @@ void AbstractByteArrayViewPrivate::setByteArrayModel( AbstractByteArrayModel* by
 
 void AbstractByteArrayViewPrivate::toggleOffsetColumn( bool showOffsetColumn )
 {
+    Q_Q( AbstractByteArrayView );
+
     const bool isVisible = mOffsetColumn->isVisible();
     // no change?
     if( isVisible == showOffsetColumn )
@@ -240,6 +242,8 @@ void AbstractByteArrayViewPrivate::toggleOffsetColumn( bool showOffsetColumn )
     mOffsetColumn->setVisible( showOffsetColumn );
 
     updateViewByWidth();
+
+    emit q->offsetColumnVisibleChanged( showOffsetColumn );
 }
 
 
@@ -384,6 +388,8 @@ void AbstractByteArrayViewPrivate::setFirstLineOffset( Address firstLineOffset )
 
 void AbstractByteArrayViewPrivate::setLayoutStyle( AbstractByteArrayView::LayoutStyle layoutStyle )
 {
+    Q_Q( AbstractByteArrayView );
+
     const bool isChanged = ( mResizeStyle != layoutStyle );
 
     if( !isChanged )
@@ -391,10 +397,14 @@ void AbstractByteArrayViewPrivate::setLayoutStyle( AbstractByteArrayView::Layout
 
     mResizeStyle = layoutStyle;
     updateViewByWidth();
+
+    emit q->layoutStyleChanged( mResizeStyle );
 }
 
 void AbstractByteArrayViewPrivate::setNoOfBytesPerLine( int noOfBytesPerLine )
 {
+    Q_Q( AbstractByteArrayView );
+
     // if the number is explicitly set we expect a wish for no automatic resize
     setLayoutStyle( AbstractByteArrayView::FixedLayoutStyle );
 
@@ -402,6 +412,8 @@ void AbstractByteArrayViewPrivate::setNoOfBytesPerLine( int noOfBytesPerLine )
         return;
 
     updateViewByWidth();
+
+    emit q->noOfBytesPerLineChanged( mTableLayout->noOfBytesPerLine() );
 }
 
 
