@@ -1,7 +1,7 @@
 /*
  *   This file is part of the Okteta Kasten Framework, made within the KDE community.
  *
- *   Copyright 2009, 2010 Alex Richardson <alex.richardson@gmx.de>
+ *   Copyright 2009, 2010, 2012 Alex Richardson <alex.richardson@gmx.de>
  *
  *   This library is free software; you can redistribute it and/or
  *   modify it under the terms of the GNU Lesser General Public
@@ -21,7 +21,9 @@
  */
 #include "structuredatainformation.h"
 
-#include <KLocale>
+#include "topleveldatainformation.h"
+
+#include <KLocalizedString>
 
 StructureDataInformation::StructureDataInformation(const QString& name, DataInformation* parent)
         : DataInformationWithChildren(name, QVector<DataInformation*>(), parent)
@@ -47,3 +49,32 @@ StructureDataInformation::StructureDataInformation(const StructureDataInformatio
         : DataInformationWithChildren(d)
 {
 }
+
+qint64 StructureDataInformation::readData(Okteta::AbstractByteArrayModel *input,
+        Okteta::Address address, BitCount64 bitsRemaining, quint8* bitOffset)
+{
+    //first of all update the structure:
+    TopLevelDataInformation* top = topLevelDataInformation();
+    Q_CHECK_PTR(top);
+
+    uint readBytes = 0;
+    qint64 readBits = 0;
+    const quint8 origBitOffset = *bitOffset;
+    for (int i = 0; i < mChildren.size(); i++)
+    {
+        DataInformation* next = mChildren.at(i);
+        top->updateElement(next);
+        qint64 currentReadBits = next->readData(input, address + readBytes,
+                bitsRemaining - readBits, bitOffset);
+        if (currentReadBits == -1)
+        {
+            mWasAbleToRead = false;
+            //could not read one element -> whole structure could not be read
+            return -1;
+        }
+        readBits += currentReadBits;
+        readBytes = (readBits + origBitOffset) / 8;
+    }
+    mWasAbleToRead = true;
+    return readBits;
+}
