@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2003-2008                                               *
+ *   copyright (C) 2003-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -23,7 +23,6 @@
 #include <kcombobox.h>
 #include <klocale.h>
 #include <kmessagebox.h>
-#include <kdebug.h>
 
 // qt includes
 #include <QtGui/QLayout>
@@ -76,11 +75,11 @@ void UMLTemplateDialog::setupDialog()
 
     Dialog_Utils::makeLabeledEditField( m_pValuesGB, valuesLayout, 1,
                                     m_pNameL, i18nc("template name", "&Name:"),
-                                    m_pNameLE, m_pTemplate->getName() );
+                                    m_pNameLE, m_pTemplate->name() );
 
     Dialog_Utils::makeLabeledEditField( m_pValuesGB, valuesLayout, 2,
                                     m_pStereoTypeL, i18n("&Stereotype name:"),
-                                    m_pStereoTypeLE, m_pTemplate->getStereotype() );
+                                    m_pStereoTypeLE, m_pTemplate->stereotype() );
 
     mainLayout->addWidget(m_pValuesGB);
 
@@ -105,10 +104,10 @@ void UMLTemplateDialog::insertTypesSorted(const QString& type)
     // "class" is the nominal type of template parameter
     types << "class";
     // add the active data types to combo box
-    UMLDoc *pDoc = UMLApp::app()->getDocument();
-    UMLClassifierList namesList( pDoc->getConcepts() );
+    UMLDoc *pDoc = UMLApp::app()->document();
+    UMLClassifierList namesList( pDoc->concepts() );
     foreach (UMLClassifier* obj, namesList) {
-        types << obj->getName();
+        types << obj->name();
     }
     // add the given parameter
     if ( !types.contains(type) ) {
@@ -133,10 +132,10 @@ void UMLTemplateDialog::insertTypesSorted(const QString& type)
 bool UMLTemplateDialog::apply()
 {
     QString typeName = m_pTypeCB->currentText();
-    UMLDoc *pDoc = UMLApp::app()->getDocument();
-    UMLClassifierList namesList( pDoc->getConcepts() );
+    UMLDoc *pDoc = UMLApp::app()->document();
+    UMLClassifierList namesList( pDoc->concepts() );
     foreach (UMLClassifier* obj, namesList) {
-        if (typeName == obj->getName()) {
+        if (typeName == obj->name()) {
             m_pTemplate->setType(obj);
         }
     }
@@ -147,8 +146,8 @@ bool UMLTemplateDialog::apply()
     QString name = m_pNameLE->text();
     if( name.length() == 0 ) {
         KMessageBox::error(this, i18n("You have entered an invalid template name."),
-                           i18n("Template Name Invalid"), false);
-        m_pNameLE->setText( m_pTemplate->getName() );
+                           i18n("Template Name Invalid"), 0);
+        m_pNameLE->setText( m_pTemplate->name() );
         return false;
     }
 
@@ -157,8 +156,8 @@ bool UMLTemplateDialog::apply()
         UMLObject *o = pClass->findChildObject(name);
         if (o && o != m_pTemplate) {
             KMessageBox::error(this, i18n("The template parameter name you have chosen is already being used in this operation."),
-                               i18n("Template Name Not Unique"), false);
-            m_pNameLE->setText( m_pTemplate->getName() );
+                               i18n("Template Name Not Unique"), 0);
+            m_pNameLE->setText( m_pTemplate->name() );
             return false;
         }
     }
